# Table of Contents

- [creating-and-linking-fact-sheets-and-jira-issues](<./creating-and-linking-fact-sheets-and-jira-issues.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Importing, Exporting, and Linking Fact Sheets and Jira Work Items](<./Importing-Exporting-and-Linking-Fact-Sheets-and-Jira-Work-Items.md>)
  - [Importing Jira Work Items as Child Initiative Fact Sheets](<./Importing-Exporting-and-Linking-Fact-Sheets-and-Jira-Work-Items/Importing-Jira-Work-Items-as-Child-Initiative-Fact-Sheets.md>)
  - [Exporting Initiative Fact Sheets as Jira Work Items](<./Importing-Exporting-and-Linking-Fact-Sheets-and-Jira-Work-Items/Exporting-Initiative-Fact-Sheets-as-Jira-Work-Items.md>)
  - [Linking an Existing Initiative Fact Sheet to an Existing Jira Work Item](<./Importing-Exporting-and-Linking-Fact-Sheets-and-Jira-Work-Items/Linking-an-Existing-Initiative-Fact-Sheet-to-an-Existing-Jira-Work-Item.md>)
  - [Searching and Filtering for Jira Work Items](<./Importing-Exporting-and-Linking-Fact-Sheets-and-Jira-Work-Items/Searching-and-Filtering-for-Jira-Work-Items.md>)
  - [Setting Up Automated Import Rules](<./Importing-Exporting-and-Linking-Fact-Sheets-and-Jira-Work-Items/Setting-Up-Automated-Import-Rules.md>)
  - [Editing Import Rules](<./Importing-Exporting-and-Linking-Fact-Sheets-and-Jira-Work-Items/Editing-Import-Rules.md>)
  - [Turning Off Import Rules](<./Importing-Exporting-and-Linking-Fact-Sheets-and-Jira-Work-Items/Turning-Off-Import-Rules.md>)
  - [Deleting Import Rules](<./Importing-Exporting-and-Linking-Fact-Sheets-and-Jira-Work-Items/Deleting-Import-Rules.md>)
